@@ -212,9 +212,10 @@ text3d      <- function(x, y = NULL, z = NULL,
 }
 texts3d	    <- text3d
 
-spheres3d   <- function(x,y=NULL,z=NULL,radius=1,...) {
+spheres3d   <- function(x, y = NULL, z = NULL, radius = 1, fastTransparency = TRUE, ...) {
   .check3d(); save <- material3d(); on.exit(material3d(save))
-  do.call("rgl.spheres", c(list(x=x,y=y,z=z,radius=radius), .fixMaterialArgs(..., Params = save)))
+  do.call("rgl.spheres", c(list(x = x, y = y, z = z, 
+  															radius = radius, fastTransparency = fastTransparency), .fixMaterialArgs(..., Params = save)))
 }
 
 planes3d   <- function(a,b=NULL,c=NULL,d=0,...) {
@@ -232,7 +233,9 @@ abclines3d   <- function(x,y=NULL,z=NULL,a,b=NULL,c=NULL,...) {
   do.call("rgl.abclines", c(list(x=x,y=y,z=z,a=a,b=b,c=c), .fixMaterialArgs(..., Params = save)))
 }
 
-sprites3d   <- function(x,y=NULL,z=NULL,radius=1,shapes=NULL,userMatrix,...) {
+sprites3d   <- function(x, y = NULL, z = NULL, radius = 1, 
+												shapes = NULL, userMatrix,
+												fixedSize = FALSE, ...) {
   .check3d(); save <- material3d(); on.exit(material3d(save))
   if (missing(userMatrix)) {
     userMatrix <- getr3dDefaults()$userMatrix
@@ -244,7 +247,7 @@ sprites3d   <- function(x,y=NULL,z=NULL,radius=1,shapes=NULL,userMatrix,...) {
   par3d(ignoreExtent=savepar$ignoreExtent)
 
   do.call("rgl.sprites", c(list(x=x,y=y,z=z,radius=radius,shapes=shapes,
-                                userMatrix=userMatrix), 
+                                userMatrix=userMatrix, fixedSize = fixedSize), 
           .fixMaterialArgs(..., Params = save)))
 }
 
@@ -298,8 +301,14 @@ r3dDefaults <- list(userMatrix = rotationMatrix(290*pi/180, 1, 0, 0),
 		  family = "sans",
 		  material = list(color="black", fog = TRUE))
 
+if (.Platform$OS.type == "windows")
+	r3dDefaults$useFreeType <- FALSE
+
 open3d <- function(..., params = getr3dDefaults(), 
                    useNULL = rgl.useNULL(), silent = FALSE	) {
+	
+	  register_pkgdown_methods()
+	
     args <- list(...)
     if (!is.null(args$antialias) 
         || !is.null(args$antialias <- r3dDefaults$antialias)) {
