@@ -1,5 +1,14 @@
 #ifndef RGL_CONFIG_H
 #define RGL_CONFIG_H
+
+#ifdef RGL_NO_OPENGL
+
+#undef RGL_OSX
+#undef RGL_X11
+#undef RGL_W32
+
+#else
+
 // ---------------------------------------------------------------------------
 // Platform detection
 // ---------------------------------------------------------------------------
@@ -15,5 +24,7 @@
 # endif
 #endif
 // ---------------------------------------------------------------------------
+#endif
+
 #endif //RGL_CONFIG_H
 
